CVS commit: src/sys/external/bsd/compiler_rt/dist/lib/builtins

2016-03-24 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Fri Mar 25 03:51:19 UTC 2016

Modified Files:
src/sys/external/bsd/compiler_rt/dist/lib/builtins: int_types.h

Log Message:
No CRT_HAS_128BIT for pcc, which lacks attribute((mode(TI))).


To generate a diff of this commit:
cvs rdiff -u -r1.1.1.4 -r1.2 \
src/sys/external/bsd/compiler_rt/dist/lib/builtins/int_types.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/external/bsd/compiler_rt/dist/lib/builtins/int_types.h
diff -u src/sys/external/bsd/compiler_rt/dist/lib/builtins/int_types.h:1.1.1.4 src/sys/external/bsd/compiler_rt/dist/lib/builtins/int_types.h:1.2
--- src/sys/external/bsd/compiler_rt/dist/lib/builtins/int_types.h:1.1.1.4	Sat Feb 27 18:59:30 2016
+++ src/sys/external/bsd/compiler_rt/dist/lib/builtins/int_types.h	Fri Mar 25 03:51:19 2016
@@ -62,7 +62,8 @@ typedef union
 
 /* MIPS64 issue: PR 20098 */
 #if (defined(__LP64__) || defined(__wasm__)) && \
-!(defined(__mips__) && defined(__clang__))
+!(defined(__mips__) && defined(__clang__)) && \
+!defined(__PCC__)
 #define CRT_HAS_128BIT
 #endif
 



CVS commit: src/external/gpl3/gcc

2016-03-24 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Mar 24 21:46:28 UTC 2016

Modified Files:
src/external/gpl3/gcc: README.gcc53

Log Message:
update VAX


To generate a diff of this commit:
cvs rdiff -u -r1.12 -r1.13 src/external/gpl3/gcc/README.gcc53

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/README.gcc53
diff -u src/external/gpl3/gcc/README.gcc53:1.12 src/external/gpl3/gcc/README.gcc53:1.13
--- src/external/gpl3/gcc/README.gcc53:1.12	Thu Mar 24 17:26:45 2016
+++ src/external/gpl3/gcc/README.gcc53	Thu Mar 24 17:46:28 2016
@@ -1,4 +1,4 @@
-$NetBSD: README.gcc53,v 1.12 2016/03/24 21:26:45 skrll Exp $
+$NetBSD: README.gcc53,v 1.13 2016/03/24 21:46:28 christos Exp $
 
 lib:
 	libasan is disabled currently (haven't tried yet)
@@ -66,7 +66,7 @@ sh3eb		y	?	y	y		y[5]
 sh3el		y	?	y	y		y
 sparc		y	y	y	y		y		y
 sparc64		y	y	y	y		y		y[6,2]	y
-vax		n[7]
+vax		y	y	y	y		y		y[15]	n
 x86_64		y	y	y	y		y		y	y
 --
 or1k		n[11]
@@ -113,3 +113,7 @@ architecture	tools	kernels	libgcc	native
- pmax gxemul (OK)
- i386/amd64 (OK)
- hppa (OK)
+[15] - vax
+	- ssh is broken, was broken with 4.8
+	- there are too many -O0's we added because of mis-handled rtl
+	- the eh_frame stuff is probably busted, but it never worked?



CVS commit: src/external/gpl3/gcc

2016-03-24 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Mar 24 21:26:45 UTC 2016

Modified Files:
src/external/gpl3/gcc: README.gcc53

Log Message:
hppa is tested. I think it's "OK"


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.12 src/external/gpl3/gcc/README.gcc53

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/README.gcc53
diff -u src/external/gpl3/gcc/README.gcc53:1.11 src/external/gpl3/gcc/README.gcc53:1.12
--- src/external/gpl3/gcc/README.gcc53:1.11	Thu Mar 24 21:20:31 2016
+++ src/external/gpl3/gcc/README.gcc53	Thu Mar 24 21:26:45 2016
@@ -1,4 +1,4 @@
-$NetBSD: README.gcc53,v 1.11 2016/03/24 21:20:31 mrg Exp $
+$NetBSD: README.gcc53,v 1.12 2016/03/24 21:26:45 skrll Exp $
 
 lib:
 	libasan is disabled currently (haven't tried yet)
@@ -112,3 +112,4 @@ architecture	tools	kernels	libgcc	native
- evbmips gxemul MALTA (FAIL - not gcc problem)
- pmax gxemul (OK)
- i386/amd64 (OK)
+   - hppa (OK)



CVS commit: src/external/gpl3/gcc

2016-03-24 Thread matthew green
Module Name:src
Committed By:   mrg
Date:   Thu Mar 24 21:20:31 UTC 2016

Modified Files:
src/external/gpl3/gcc: README.gcc53

Log Message:
update:
- earmv4 works (atf has one new failure, that seems common)
- mipsel run
- sparc runs
- sparc64 mostly works in UP mode
- add list of actual machines tested on


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/external/gpl3/gcc/README.gcc53

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/README.gcc53
diff -u src/external/gpl3/gcc/README.gcc53:1.10 src/external/gpl3/gcc/README.gcc53:1.11
--- src/external/gpl3/gcc/README.gcc53:1.10	Thu Mar 24 21:10:21 2016
+++ src/external/gpl3/gcc/README.gcc53	Thu Mar 24 21:20:31 2016
@@ -1,4 +1,4 @@
-$NetBSD: README.gcc53,v 1.10 2016/03/24 21:10:21 skrll Exp $
+$NetBSD: README.gcc53,v 1.11 2016/03/24 21:20:31 mrg Exp $
 
 lib:
 	libasan is disabled currently (haven't tried yet)
@@ -43,7 +43,7 @@ earm		y	?	y	y		y[3,13]
 earmeb		y	?	y	y		y[3,13]
 earmhf		y	?	y	y		y[3]
 earmhfeb	y	?	y	y		y[3]
-earmv4		y	y	y	y		y[3]		y
+earmv4		y	y	y	y		y[3]		y	y[4]
 earmv4eb	y	?	y	y		y[3]
 earmv6		y	?	y	y		y[3]
 earmv6eb	y	?	y	y		y[3]
@@ -58,14 +58,14 @@ i386		y	y	y	y		y		y	
 m68000		y	?	y	y		y
 m68k		y	?	y	y		y[13]
 mipseb		y	?	y	y		y
-mipsel		y	?	y	y		y
+mipsel		y	y	y	y		y		y
 mips64eb	y	?	n	y		n[8]
 mips64el	y	?	n	y		y[8]
 powerpc		y	y	y	y		y		y[6]	
 sh3eb		y	?	y	y		y[5]
 sh3el		y	?	y	y		y
-sparc		y	y	y	y		y		y[1]
-sparc64		y	y	y	y		y		n[6,2]	y[9]
+sparc		y	y	y	y		y		y
+sparc64		y	y	y	y		y		y[6,2]	y
 vax		n[7]
 x86_64		y	y	y	y		y		y	y
 --
@@ -78,13 +78,12 @@ powerpc64
 architecture	tools	kernels	libgcc	native-gcc	make release	runs	atf
 
 
-[1] - world built without -fno-delete-null-pointer-checks does not have a
-  working sshd
+[1] - 
 [2] - -O2 and -Os kernels hang, -O1 SIR reset
 	-- may be a SMP issue; ultra10 works, ultra45 SMP does not
 		-- try sb2000 (particularly with UP kernel.  u45 UP is shitty.)
 [3] - MKCOMPAT=no enabled currently, infact OABI seems to be broken.  the docs say it was only deprecated, but the options make broken crap.
-[4]
+[4] - bin/expr/t_expr:overflow fails on shark, only new failure.  fails on other ports too.
 [5] - sh3eb tries to use sh specific atomic config which doesn't work, has hand edited mknative output
 [6] - sshd is broken, regardless of compiler options
 	-- libldap.so.4.3 is broken on sparc64; replacing just this fixes sshd.
@@ -92,7 +91,7 @@ architecture	tools	kernels	libgcc	native
 	-- it is not binutils 2.23 vs 2.26
 [7] - GCC fails to build
 [8] - sgimips64 release build fails, mdsetimage'd gz'd kernels don't get built?
-[9] - with a 4.8 base.tgz and 5.3 everythingelse.tgz, about 60 additional failures out of ~3800
+[9] - 
 [10] - fails to build tools with:
 	/usr/src8/tools/gcc/../../external/gpl3/gcc/dist/gcc/config/riscv/riscv.h:1087:9: error: attempt to use poisoned "MOVE_BY_PIECES_P"
 	 #define MOVE_BY_PIECES_P(SIZE, ALIGN)\
@@ -104,3 +103,12 @@ architecture	tools	kernels	libgcc	native
- earm : shark evbarm*
- mipsel: sgimips
- mips64el: sgimips[fail] evbmips
+[14] - machines tested:
+   - sparc ss20 (OK)
+   - sparc64 ultra45 (FAIL), ultra10 (OK)
+   - powerpc pegasosII (OK)
+   - alpha UP1000 (OK)
+   - arm shark (OK)
+   - evbmips gxemul MALTA (FAIL - not gcc problem)
+   - pmax gxemul (OK)
+   - i386/amd64 (OK)



CVS commit: src/external/gpl3/gcc

2016-03-24 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Mar 24 21:10:21 UTC 2016

Modified Files:
src/external/gpl3/gcc: README.gcc53

Log Message:
Note hppa status:

- kernel works
- sshd has the ldap problem


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 src/external/gpl3/gcc/README.gcc53

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gcc/README.gcc53
diff -u src/external/gpl3/gcc/README.gcc53:1.9 src/external/gpl3/gcc/README.gcc53:1.10
--- src/external/gpl3/gcc/README.gcc53:1.9	Wed Mar 23 18:45:41 2016
+++ src/external/gpl3/gcc/README.gcc53	Thu Mar 24 21:10:21 2016
@@ -1,4 +1,4 @@
-$NetBSD: README.gcc53,v 1.9 2016/03/23 18:45:41 mrg Exp $
+$NetBSD: README.gcc53,v 1.10 2016/03/24 21:10:21 skrll Exp $
 
 lib:
 	libasan is disabled currently (haven't tried yet)
@@ -53,7 +53,7 @@ earmv7		y	?	y	y		y[3]
 earmv7eb	y	?	y	y		y[3]
 earmv7hf	y	?	y	y		y[3]
 earmv7hfeb	y	?	y	y		y[3]
-hppa		y	?	y	y		y
+hppa		y	y	y	y		y		y[6]	y
 i386		y	y	y	y		y		y	
 m68000		y	?	y	y		y
 m68k		y	?	y	y		y[13]



CVS commit: src/usr.sbin/makemandb

2016-03-24 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Mar 24 17:28:03 UTC 2016

Modified Files:
src/usr.sbin/makemandb: makemandb.c

Log Message:
PR/51006: Abhinav Upadhyay: makemandb(8) should parse escape sequences
in the NAME section


To generate a diff of this commit:
cvs rdiff -u -r1.31 -r1.32 src/usr.sbin/makemandb/makemandb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/makemandb/makemandb.c
diff -u src/usr.sbin/makemandb/makemandb.c:1.31 src/usr.sbin/makemandb/makemandb.c:1.32
--- src/usr.sbin/makemandb/makemandb.c:1.31	Wed Jan 27 22:32:29 2016
+++ src/usr.sbin/makemandb/makemandb.c	Thu Mar 24 13:28:03 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: makemandb.c,v 1.31 2016/01/28 03:32:29 christos Exp $	*/
+/*	$NetBSD: makemandb.c,v 1.32 2016/03/24 17:28:03 christos Exp $	*/
 /*
  * Copyright (c) 2011 Abhinav Upadhyay 
  * Copyright (c) 2011 Kristaps Dzonsons 
@@ -17,13 +17,12 @@
  */
 
 #include 
-__RCSID("$NetBSD: makemandb.c,v 1.31 2016/01/28 03:32:29 christos Exp $");
+__RCSID("$NetBSD: makemandb.c,v 1.32 2016/03/24 17:28:03 christos Exp $");
 
 #include 
 #include 
 
 #include 
-#include 
 #include 
 #include 
 #include 
@@ -39,7 +38,6 @@ __RCSID("$NetBSD: makemandb.c,v 1.31 201
 #include "dist/man.h"
 #include "dist/mandoc.h"
 #include "dist/mdoc.h"
-#include "sqlite3.h"
 
 #define BUFLEN 1024
 #define MDOC 0	//If the page is of mdoc(7) type
@@ -1013,7 +1011,9 @@ pmdoc_Nm(const struct mdoc_node *n, mand
 
 	for (n = n->child; n; n = n->next) {
 		if (n->type == MDOC_TEXT) {
-			concat(&rec->name, n->string);
+			char *escaped_name = parse_escape(n->string);
+			concat(&rec->name, escaped_name);
+			free(escaped_name);
 		}
 	}
 }
@@ -1045,8 +1045,7 @@ pmdoc_Nd(const struct mdoc_node *n, mand
 			concat(&rec->name_desc, buf);
 			free(buf);
 		} else {
-			nd_text = estrdup(n->string);
-			replace_hyph(nd_text);
+			nd_text = parse_escape(n->string);
 			concat(&rec->name_desc, nd_text);
 			free(nd_text);
 		}
@@ -1329,7 +1328,7 @@ pman_sh(const struct man_node *n, mandb_
 	};
 	const struct man_node *head;
 	char *name_desc;
-	int sz;
+	size_t sz;
 	size_t i;
 
 	if ((head = n->parent->head) == NULL || (head = head->child) == NULL ||



CVS commit: src/usr.sbin/makemandb

2016-03-24 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Mar 24 16:07:13 UTC 2016

Modified Files:
src/usr.sbin/makemandb: apropos-utils.c

Log Message:
PR/51004: Abhinav Upadhyay: apropos html mode doesn't handle especial
characters in the short description


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/usr.sbin/makemandb/apropos-utils.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/ohci.c
diff -u src/sys/dev/usb/ohci.c:1.254.2.59 src/sys/dev/usb/ohci.c:1.254.2.60
--- src/sys/dev/usb/ohci.c:1.254.2.59	Thu Mar 17 09:04:53 2016
+++ src/sys/dev/usb/ohci.c	Thu Mar 24 15:30:17 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: ohci.c,v 1.254.2.59 2016/03/17 09:04:53 skrll Exp $	*/
+/*	$NetBSD: ohci.c,v 1.254.2.60 2016/03/24 15:30:17 skrll Exp $	*/
 
 /*
  * Copyright (c) 1998, 2004, 2005, 2012 The NetBSD Foundation, Inc.
@@ -41,7 +41,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: ohci.c,v 1.254.2.59 2016/03/17 09:04:53 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ohci.c,v 1.254.2.60 2016/03/24 15:30:17 skrll Exp $");
 
 #include "opt_usb.h"
 
@@ -3728,6 +3728,8 @@ ohci_device_isoc_abort(struct usbd_xfer 
 	sitd = xfer->ux_hcpriv;
 	KASSERT(sitd);
 
+	usb_delay_ms_locked(&sc->sc_bus, OHCI_ITD_NOFFSET, &sc->sc_lock);
+
 	for (; sitd->xfer == xfer; sitd = sitd->nextitd) {
 		ohci_hash_rem_itd(sc, sitd);
 #ifdef DIAGNOSTIC
@@ -3736,8 +3738,6 @@ ohci_device_isoc_abort(struct usbd_xfer 
 #endif
 	}
 
-	usb_delay_ms_locked(&sc->sc_bus, OHCI_ITD_NOFFSET, &sc->sc_lock);
-
 	/* Run callback. */
 	usb_transfer_complete(xfer);
 



CVS commit: src/share/mk

2016-03-24 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Thu Mar 24 09:15:38 UTC 2016

Modified Files:
src/share/mk: bsd.own.mk

Log Message:
Switch mips64 over to new gdb - old one doesn't work there either, better
to debug in the newer version.


To generate a diff of this commit:
cvs rdiff -u -r1.909 -r1.910 src/share/mk/bsd.own.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/mk/bsd.own.mk
diff -u src/share/mk/bsd.own.mk:1.909 src/share/mk/bsd.own.mk:1.910
--- src/share/mk/bsd.own.mk:1.909	Thu Mar 24 04:28:49 2016
+++ src/share/mk/bsd.own.mk	Thu Mar 24 09:15:38 2016
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.own.mk,v 1.909 2016/03/24 04:28:49 christos Exp $
+#	$NetBSD: bsd.own.mk,v 1.910 2016/03/24 09:15:38 martin Exp $
 
 # This needs to be before bsd.init.mk
 .if defined(BSD_MK_COMPAT_FILE)
@@ -132,7 +132,8 @@ USE_SSP?=	yes
 .if ${MACHINE} == "amd64" || \
 ${MACHINE} == "i386" || \
 ${MACHINE_CPU} == "sh3" || \
-${MACHINE_ARCH} == "vax"
+${MACHINE_ARCH} == "vax" || \
+${MACHINE_ARCH} == "mips64eb" || ${MACHINE_ARCH} == "mips64el"
 HAVE_GDB?=	710
 .else
 HAVE_GDB?=	79
Index: src/usr.sbin/makemandb/apropos-utils.c
diff -u src/usr.sbin/makemandb/apropos-utils.c:1.20 src/usr.sbin/makemandb/apropos-utils.c:1.21
--- src/usr.sbin/makemandb/apropos-utils.c:1.20	Sun Mar 20 13:31:09 2016
+++ src/usr.sbin/makemandb/apropos-utils.c	Thu Mar 24 12:07:13 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: apropos-utils.c,v 1.20 2016/03/20 17:31:09 christos Exp $	*/
+/*	$NetBSD: apropos-utils.c,v 1.21 2016/03/24 16:07:13 christos Exp $	*/
 /*-
  * Copyright (c) 2011 Abhinav Upadhyay 
  * All rights reserved.
@@ -31,7 +31,7 @@
  */
 
 #include 
-__RCSID("$NetBSD: apropos-utils.c,v 1.20 2016/03/20 17:31:09 christos Exp $");
+__RCSID("$NetBSD: apropos-utils.c,v 1.21 2016/03/24 16:07:13 christos Exp $");
 
 #include 
 #include 
@@ -625,87 +625,95 @@ run_query_internal(sqlite3 *db, const ch
 	return *(args->errmsg) == NULL ? 0 : -1;
 }
 
-/*
- * callback_html --
- *  Callback function for run_query_html. It builds the html output and then
- *  calls the actual user supplied callback function.
- */
-static int
-callback_html(void *data, const char *section, const char *name,
-	const char *name_desc, const char *snippet, size_t snippet_length)
+static char *
+get_escaped_html_string(const char *src, size_t *slen)
 {
-	const char *temp = snippet;
-	int i = 0;
-	size_t sz = 0;
-	int count = 0;
-	struct orig_callback_data *orig_data = (struct orig_callback_data *) data;
-	int (*callback) (void *, const char *, const char *, const char *,
-		const char *, size_t) = orig_data->callback;
-
-	/* First scan the snippet to find out the number of occurrences of {'>', '<'
-	 * '"', '&'}.
-	 * Then allocate a new buffer with sufficient space to be able to store the
-	 * quoted versions of the special characters {>, <, ", &}.
-	 * Copy over the characters from the original snippet to this buffer while
-	 * replacing the special characters with their quoted versions.
+	static const char trouble[] = "<>\"&\002\003";
+	/*
+	 * First scan the src to find out the number of occurrences
+	 * of {'>', '<' '"', '&'}.  Then allocate a new buffer with
+	 * sufficient space to be able to store the quoted versions
+	 * of the special characters {>, <, ", &}.
+	 * Copy over the characters from the original src into
+	 * this buffer while replacing the special characters with
+	 * their quoted versions.
 	 */
+	char *dst, *ddst;
+	size_t count;
+	const char *ssrc;
+
+	for (count = 0, ssrc = src; *src; count++) {
+		size_t sz = strcspn(src, trouble);
+		src += sz + 1;
+	}
 
-	while (*temp) {
-		sz = strcspn(temp, "<>\"&\002\003");
-		temp += sz + 1;
-		count++;
-	}
-	size_t qsnippet_length = snippet_length + count * 5;
-	char *qsnippet = emalloc(qsnippet_length + 1);
-	sz = 0;
-	while (*snippet) {
-		sz = strcspn(snippet, "<>\"&\002\003");
-		if (sz) {
-			memcpy(&qsnippet[i], snippet, sz);
-			snippet += sz;
-			i += sz;
-		}
 
-		switch (*snippet++) {
+#define append(a)	do {		\
+memcpy(dst, (a), sizeof(a) - 1);	\
+dst += sizeof(a) - 1; 			\
+			} while (/*CONSTCOND*/0)
+
+	ddst = dst = emalloc(*slen + count * 5 + 1);
+	for (src = ssrc; *src; src++) {
+		switch (*src) {
 		case '<':
-			memcpy(&qsnippet[i], "<", 4);
-			i += 4;
+			append("<");
 			break;
 		case '>':
-			memcpy(&qsnippet[i], ">", 4);
-			i += 4;
+			append(">");
 			break;
 		case '\"':
-			memcpy(&qsnippet[i], """, 6);
-			i += 6;
+			append(""");
 			break;
 		case '&':
-			/* Don't perform the quoting if this & is part of an mdoc escape
-			 * sequence, e.g. \&
+			/*
+			 * Don't perform the quoting if this & is part of
+			 * an mdoc escape sequence, e.g. \&
 			 */
-			if (i && *(snippet - 2) != '\\') {
-memcpy(&qsnippet[i], "&", 5);
-i += 5;
-			} else {
-qsnippet[i++] = '&';
-			}
+			if (src != ssrc && src[-1] != '\\')
+append("&");
+			else
+append("&");
 			break;
 		case '\002':
-			memcpy(&qsnippet[i], "", 3);
-			i += 3;
+			append("");
 			break;
 		case '\003':
-			memcpy(&qsnippet[i], "", 4);
-			i += 4;
+			append("");
 			break;
 		default:
+			*dst++ = *src;
 			break;
 		}
 	}
-	qsnippet[i] = 0;
-	(*callback)(orig_data->data, section, name, name_desc,
-		(const char *)qsnippet,	strlen(qsnippet));
+	*dst = '\0';
+	*slen = dst - ddst;
+	return ddst;
+}
+
+
+/*
+ * callback_html --
+ *  Callback function for run_query_html. It builds the html output and then
+ *  calls the actual user supplied callback function.
+ */
+static int
+callback_html(void *data, const char *section, const char *name,
+const char *name_desc, 

CVS commit: [nick-nhusb] src/sys/dev/usb

2016-03-24 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Mar 24 15:30:17 UTC 2016

Modified Files:
src/sys/dev/usb [nick-nhusb]: ohci.c

Log Message:
Wait for hardware before removing the TDs from the hash lists.

This is all a bit racey and should be revisited.


To generate a diff of this commit:
cvs rdiff -u -r1.254.2.59 -r1.254.2.60 src/sys/dev/usb/ohci.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
